/*
    Парус 8 - Панели мониторинга - ТОиР - Прогнозирование технического состояния
    Закладка прогнозирования
*/

//---------------------
//Подключение библиотек
//---------------------

import React, { useState } from "react"; //Классы React
import { Box, Grid } from "@mui/material"; //Интерфейсные компоненты
import { RichTreeView } from "@mui/x-tree-view/RichTreeView"; //Дерево
import { useEqConfigTree, needLoadLevel } from "./forecast_tab_hooks"; //Вспомогательные хуки

//---------
//Константы
//---------

//Высота главного меню
const APP_BAR_HEIGHT = "64px";

//Высота закладок
const TABS_HEIGHT = "49px";

//Стили
const STYLES = {
    LEFT_SIDE_GRID: { backgroundColor: "red" },
    RIGHT_SIDE_GRID: { backgroundColor: "green" },
    TREE_BOX: {
        minHeight: `calc(100vh - ${APP_BAR_HEIGHT} - ${TABS_HEIGHT})`,
        maxHeight: `calc(100vh - ${APP_BAR_HEIGHT} - ${TABS_HEIGHT})`,
        backgroundColor: "yellow",
        overflowX: "hidden",
        overflowY: "auto",
        scrollbarWidth: "thin",
        scrollbarColor: "red blue"
    }
};

//-----------
//Тело модуля
//-----------

//Закладка прогнозирования
const ForecastTab = () => {
    //Собственное состояние - текущая загружаемая ветка
    const [loadingTreeItem, setLoadingTreeItem] = useState(0);

    //Загрузчик веток дерева
    const { tree } = useEqConfigTree(loadingTreeItem);

    //Обработка развёртывания/свёртывания уровня дерева
    const handleTreeItemExpansionToggle = (event, itemId, isExpanded) =>
        isExpanded && needLoadLevel(tree, itemId) ? setLoadingTreeItem(parseInt(itemId)) : null;

    //Обработка фокусировки на элементе дерева
    const handleTreeItemFocus = (event, itemId, isExpanded) => console.log(event, itemId, isExpanded);

    //Генерация содержимого
    return (
        <div>
            <Grid container>
                <Grid item xs={4} sx={STYLES.LEFT_SIDE_GRID}>
                    <Box sx={STYLES.TREE_BOX}>
                        <RichTreeView items={tree} onItemExpansionToggle={handleTreeItemExpansionToggle} onItemFocus={handleTreeItemFocus} />
                    </Box>
                </Grid>
                <Grid item xs={8} sx={STYLES.RIGHT_SIDE_GRID}>
                    ОБОРУДОВАНИЕ
                </Grid>
            </Grid>
        </div>
    );
};

//----------------
//Интерфейс модуля
//----------------

export { ForecastTab };
