/*
    Парус 8 - Панели мониторинга - ТОиР - Прогнозирование технического состояния
    Кастомные хуки закладки Прогнозирования
*/

//---------------------
//Подключение библиотек
//---------------------

import { useState, useEffect, useContext } from "react"; //Классы React
import { BackEndСtx } from "../../context/backend"; //Контекст взаимодействия с сервером
import { deepCopyObject } from "../../core/utils"; //Утилиты

//-----------------------
//Вспомогательные функции
//-----------------------

//Проверка необходимости загрузки уровня для указанного родителя
const needLoadLevel = (tree, parent) => {
    let res = false;
    tree.forEach(treeItem => {
        if (treeItem.id == parent) {
            if (treeItem.children && treeItem.children.length == 1 && treeItem.children[0].id.endsWith("loader")) res = true;
        }
        if (treeItem.children && treeItem.children.length > 0 && !treeItem.children[0].id.endsWith("loader"))
            res = needLoadLevel(treeItem.children, parent);
    });
    return res;
};

//Встраивание уровня в указанного родителя
const appendLevel = (tree, parent, children) => {
    tree.forEach(treeItem => {
        if (treeItem.id == parent) {
            treeItem.children = children;
            return;
        }
        if (treeItem.children && treeItem.children.length > 0 && !treeItem.children[0].id.endsWith("loader"))
            appendLevel(treeItem.children, parent, children);
    });
};

//-----------
//Тело модуля
//-----------

//Загрузка ветки дерева состава оборудования
const useEqConfigTree = parent => {
    //Собственное состояние - флаг загрузки
    const [isLoading, setLoading] = useState(false);

    //Собственное состояние - данные дерева
    const [tree, setTree] = useState([]);

    //Подключение к контексту взаимодействия с сервером
    const { executeStored } = useContext(BackEndСtx);

    //Загрузка данных при изменении зависимостей
    useEffect(() => {
        const loadData = async () => {
            try {
                setLoading(true);
                const data = await executeStored({
                    stored: "UDO_PKG_EQUIPTCF.EQCONFIG_HIER",
                    args: {
                        NPEQCONFIG: parent
                    },
                    respArg: "COUT",
                    isArray: name => ["children"].includes(name),
                    attributeValueProcessor: (name, val) => (["id"].includes(name) ? undefined : val),
                    loader: false
                });
                setTree(prevTree => {
                    if (prevTree.length == 0) return data.children;
                    else {
                        let newTree = deepCopyObject(prevTree);
                        appendLevel(newTree, parent, data.children);
                        return newTree;
                    }
                });
            } finally {
                setLoading(false);
            }
        };
        if (parent == 0 || parent) loadData();
    }, [parent, executeStored]);

    //Вернём данные
    return { tree, isLoading };
};

//----------------
//Интерфейс модуля
//----------------

export { useEqConfigTree, needLoadLevel };
